#!/bin/bash
#

extraqual=${1}
basequal=${2}

pkgver=v1_12_1
pkgdotver=1.12.1

if [ -z ${basequal} ]
then
    basequal=gcc46
fi

if [ "${extraqual}" = "opt" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG"
elif [ "${extraqual}" = "debug" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-g -O0"
elif [ "${extraqual}" = "prof" ]
then
    fullqual=${basequal}:${extraqual}
    qualdir=${basequal}-${extraqual}
    cxxflg="-O3 -g -DNDEBUG -fno-omit-frame-pointer"
else
    # default CXXFLAGS are -g -O2
    fullqual=${basequal}
    qualdir=${basequal}
fi

if [ "${basequal}" = "e1" ]
then
  cxxflg="${cxxflg} -std=c++0x -Wno-deprecated-declarations"
fi

echo "compiling for ${fullqual}"

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
pkgdir=${PRODUCTS}/cppunit/${pkgver}/${flvr}-${qualdir}

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

# setup gcc v4_6_1
setup gcc v4_6_1
gccver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.6" ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

mkdir -p ${pkgdir}/build
if [ ! -d ${pkgdir}/build ]
then
   echo "ERROR: failed to create ${pkgdir}/build"
   exit 1
fi
cd ${pkgdir}/build

set -x

if [ -z "${cxxflg}" ]
then
  ${pkgdir}/../source/cppunit-${pkgdotver}/configure --prefix=${pkgdir}
else
  CXXFLAGS="${cxxflg}" ${pkgdir}/../source/cppunit-${pkgdotver}/configure --prefix=${pkgdir}
fi
make 
make install 

set +x

if [ ! -d ${pkgdir}/bin ]
then
   echo "ERROR: failed to create ${pkgdir}/bin"
   echo "       Something is very wrong"
   exit 1
fi

if [ ! -d ${pkgdir}/lib ]
then
   echo "ERROR: failed to create ${pkgdir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building cppunit for flavor ${flvr}"
echo "Declaring cppunit ${pkgver} for flavor ${flvr}"
if [ ${OS} = "Darwin" ]
then
   ups declare cppunit ${pkgver} -r cppunit/${pkgver} -2 -m cppunit.table -q ${fullqual}
else 
   ups declare cppunit ${pkgver} -r cppunit/${pkgver} -4 -m cppunit.table -q ${fullqual}
fi
setup cppunit ${pkgver} -q ${fullqual}
echo "cppunit libraries are at  ${CPPUNIT_LIB}"

# fixing embedded path
mv ${CPPUNIT_FQ_DIR}/bin/cppunit-config ${CPPUNIT_FQ_DIR}/bin/cppunit-config.bak
cat ${CPPUNIT_FQ_DIR}/bin/cppunit-config.bak | sed 's%^prefix=.*$%prefix=${CPPUNIT_FQ_DIR}%' > ${CPPUNIT_FQ_DIR}/bin/cppunit-config
mv ${CPPUNIT_FQ_DIR}/lib/pkgconfig/cppunit.pc ${CPPUNIT_FQ_DIR}/lib/pkgconfig/cppunit.pc.bak
cat ${CPPUNIT_FQ_DIR}/lib/pkgconfig/cppunit.pc.bak | sed 's%^prefix=.*$%prefix=${CPPUNIT_FQ_DIR}%' > ${CPPUNIT_FQ_DIR}/lib/pkgconfig/cppunit.pc
chmod +x ${CPPUNIT_FQ_DIR}/bin/cppunit-config

exit 0
